@@ -207,28 +207,6 @@ maybe_write_session (void)
 
   save_selected = session_save = FALSE;
 
-  if (!shutting_down && global_save)
-    {
-      static GtkWidget *dialog = NULL;
-
-      if (dialog)
-	{
-	  gtk_window_present (GTK_WINDOW (dialog));
-	}
-      else
-	{
-	  dialog = gtk_message_dialog_new (NULL, 0, 
-					   GTK_MESSAGE_INFO,
-					   GTK_BUTTONS_OK, 
-					   _("Your session has been saved"));
-	  g_signal_connect (dialog, "response",
-			    G_CALLBACK (gtk_widget_destroy),
-			    NULL);
-	  g_object_add_weak_pointer (G_OBJECT (dialog), (gpointer *)&dialog);
-	  gtk_widget_show (dialog);
-	}
-    }
-
   gsm_verbose_indent (FALSE);
 }
 
@@ -325,7 +303,7 @@ free_client (Client *client)
 {
   GSList *list; 
 
-  gsm_verbose ("free_client(): %p (%s)\n", client, client->id ? client->id : "(null)");
+  gsm_verbose ("free_client(): %p (%s)\n", client, client->id ? client->id : "(unknown)");
 
   if(client->magic != CLIENT_MAGIC)
     {
@@ -668,7 +646,7 @@ start_client (Client* client)
   if (client->id || client->match_rule == MATCH_PROP)
     {
       APPEND (pending_list, client);
-      if (purge_delay)
+      if (purge_delay > 0)
 	{
 	  g_assert (client->purge_timeout_id == 0);
 	  client->purge_timeout_id = gtk_timeout_add (purge_delay, purge, client);
@@ -1164,7 +1142,7 @@ print_client (Client *client)
 {
   GSList *l;
 
-  gsm_verbose ("  id: %s\n", client->id);
+  gsm_verbose ("  id: %s\n", client->id ? client->id : "(unknown)");
   gsm_verbose ("  handle: %s\n", client->handle);
   gsm_verbose ("  connection: %p\n", client->connection);
   gsm_verbose ("  properties:\n");
@@ -1274,7 +1252,7 @@ process_save_request (Client* client, int save_type, gboolean shutdown,
       gint delay = client->handle ? warn_delay : purge_delay;
       save_state = SAVE_PHASE_1;
       save_state_changed ();
-      if (delay)
+      if (delay > 0)
 	{
 	  g_assert (warn_timeout_id == -1);
 	  warn_timeout_id = gtk_timeout_add (delay, no_response_warning, NULL);
@@ -1405,7 +1383,7 @@ update_save_state (void)
 	      gtk_timeout_remove (warn_timeout_id);
 	      warn_timeout_id = -1;
 	    }
-	  if (warn_delay)
+	  if (warn_delay > 0)
 	    {
 	      g_assert (warn_timeout_id == -1);
 	      warn_timeout_id = gtk_timeout_add (warn_delay, 
@@ -1462,7 +1440,7 @@ update_save_state (void)
 	  run_shutdown_commands (zombie_list);
 	  run_shutdown_commands (live_list);
 
-	  if (suicide_delay)
+	  if (suicide_delay > 0)
 	    {
 	      g_assert (warn_timeout_id == -1);
 	      warn_timeout_id = gtk_timeout_add (suicide_delay, 
